type CurverType = "Curve" | "Polyline" | "Rect" | "Line" | "Arc" | "Circle";
type EntityType = "Entity" | "ExtrudeSolid" | "Board" | "Template" | "EntityTree" | "Hardware" | "Topline";
export type PolylineContour = {
    pt: [number, number];
    bul: 0;
}[];
export type CircleContour = {
    Radius: number;
    Center: [number, number, number];
};
type ExtrudeContour = PolylineContour | CircleContour;
export interface CFDoc {
    ModelSpace: CFEntity[];
}
export interface CFEntity {
    Type: EntityType | CurverType;
    Id?: number;
    ColorIndex?: number;
    OCS?: number[];
    Pos?: [number, number, number];
    Rot?: [number, number, number];
    Qua?: [number, number, number, number];
}
export interface CFExtrudeSolid extends CFEntity {
    Width?: number;
    Height?: number;
    ContourCurve?: ExtrudeContour;
    Thickness?: number;
    GroovesAddLength?: number;
    GroovesAddWidth?: number;
    GroovesAddDepth?: number;
    KnifeRadius?: number;
    Holes?: CFExtrudeSolid[];
}
export interface CFBoard extends CFExtrudeSolid {
    Name?: string;
    BrType?: number;
    PositionType?: number;
    OpenDir?: number;
    Lines?: number;
    BigHole?: number;
    ComposingFace?: number;
    RoomName?: string;
    CabinetName?: string;
    BrMatName?: string;
    Matrial?: string;
    Color?: string;
    BoardMaterialId?: string;
    UpSealed?: string;
    DownSealed?: string;
    LeftSealed?: string;
    RightSealed?: string;
    EachSealeds?: {
        size: number;
    }[];
    EachEdgeDrills?: string[];
    FrontDrill?: boolean;
    BackDrill?: boolean;
    Remarks?: [string, string][];
}
export interface CFEntityTree extends CFEntity {
    Name?: string;
    Entitys?: CFEntity[];
    Childen?: CFEntityTree[];
}
export interface CFTemplate extends CFEntity {
    TempalteId?: string;
    Name?: string;
    Lenght?: number;
    Width?: number;
    Height?: number;
    BoxSize?: [number, number, number];
    ParamMap?: {
        name: string;
        value: string;
    }[];
    RoomName?: string;
    CabinetName?: string;
}
export interface CFHardware extends CFTemplate {
    Name?: string;
    HardwarerId?: string;
    Unit?: string;
    ActualExpr?: string;
    Model?: string;
    Factory?: string;
    Brand?: string;
    Spec?: string;
    Comments?: string;
    IsHole?: boolean;
    Material?: string;
    Color?: string;
}
export interface CFTopline extends CFTemplate {
    Name?: string;
    ToplineId?: string;
    Unit?: string;
    ActualExpr?: string;
    Model?: string;
    Factory?: string;
    Brand?: string;
    Spec?: string;
    Comments?: string;
    Contour?: {
        pt: [number, number];
        bul: 0;
    }[];
    PathCurve?: ExtrudeContour;
}
export interface CFCurve extends CFEntity {
}
export interface CFLine extends CFCurve {
    StartPoint: [number, number, number];
    EndPoint: [number, number, number];
}
export interface CFPolyline extends CFCurve {
    ContourCurve?: {
        pt: [number, number];
        bul: 0;
    }[];
}
export interface CFRect extends CFCurve {
    Width: number;
    Height: number;
}
export interface CFCircle extends CFCurve {
    Radius: number;
    Center: [number, number, number];
}
export {};
//# sourceMappingURL=CFInterface.d.ts.map